@@ -408,6 +408,7 @@ class OrderStatusEnum(str, Enum):
 
 
 class CardBrandEnum(str, Enum):
+    NONE = ""
     VISA = "VISA"
     MASTER = "MASTER"
     AMEX = "AMEX"
@@ -415,9 +416,9 @@ class CardBrandEnum(str, Enum):
     MOBILE_BANKING = "MOBILE BANKING"
 
 
-class RiskLevelEnum(int, Enum):
-    HIGH = 1
-    LOW = 0
+class RiskLevelEnum(str, Enum):
+    HIGH = "1"
+    LOW = "0"
 
 
 class BaseOrderResponse(BaseModel):
@@ -590,7 +591,6 @@ class Session(BaseModel):
     store_amount: Decimal
     card_type: str
     card_no: str
-    currency: str
     bank_tran_id: str
     card_issuer: str
     card_brand: CardBrandEnum
@@ -598,16 +598,18 @@ class Session(BaseModel):
     card_issuer_country_code: str
     currency_type: str
     currency_amount: Decimal
-    emi_instalment: int
-    emi_amount: Decimal
-    discount_percentage: Decimal
-    discount_remarks: str
+    risk_level: RiskLevelEnum
+    risk_title: str
+
+    currency: Optional[str]
+    emi_instalment: Optional[int]
+    emi_amount: Optional[int]
+    discount_percentage: Optional[Decimal]
+    discount_remarks: Optional[str]
     value_a: Optional[str]
     value_b: Optional[str]
     value_c: Optional[str]
     value_d: Optional[str]
-    risk_level: RiskLevelEnum
-    risk_title: str
 
 
 class TransactionBySessionResponse(Session):
